@@ -1,4 +1,29 @@
 
+// -*- mode: c++; c-basic-offset:4 -*-
+
+// This file is part of libdap, A C++ implementation of the OPeNDAP Data
+// Access Protocol.
+
+// Copyright (c) 2002,2003,2005 OPeNDAP, Inc.
+// Author: James Gallagher <jgallagher@opendap.org>
+//         Reza Nekovei <reza@intcomm.net>
+//
+// This library is free software; you can redistribute it and/or
+// modify it under the terms of the GNU Lesser General Public
+// License as published by the Free Software Foundation; either
+// version 2.1 of the License, or (at your option) any later version.
+// 
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+// Lesser General Public License for more details.
+// 
+// You should have received a copy of the GNU Lesser General Public
+// License along with this library; if not, write to the Free Software
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+//
+// You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
+
 // (c) COPYRIGHT URI/MIT 1994-1996
 // Please read the full copyright statement in the file COPYRIGHT.
 //
@@ -9,9 +34,12 @@
 //
 // jhrg 9/29/94
 
+// See Trac tickets #50-53
+// #define SCOPED_GRID_DIMENSIONS 1
+
 #include "config_nc.h"
 
-static char rcsid[] not_used = {"$Id: NCConnect.cc,v 1.40 2005/06/03 16:30:14 jimg Exp $"};
+static char rcsid[] not_used = {"$Id: NCConnect.cc 11983 2005-08-18 21:16:31Z jimg $"};
 
 #include "netcdf.h"
 
@@ -632,14 +660,22 @@ NCConnect::parse_grid_dims(DDS &dds)
     
     	for (Grid::Map_iter q = gr->map_begin(); q != gr->map_end(); ++q) {
     	    Array *ar = dynamic_cast<Array*>(*q);
+
+#if defined(SCOPED_GRID_DIMENSIONS)    
+            // Get dimension name; all maps are vectors in DAP 2
+            string mapdimname = gr->name() + "." + ar->dimension_name(ar->dim_begin());
+            int mapdimsize = ar->dimension_size(ar->dim_begin());
     
+            if (mapdimname == "") // if dim. name is missing use var. name 
+                    mapdimname = gr->name() + "." + ar->name();
+#else
     	    // Get dimension name; all maps are vectors in DAP 2
     	    string mapdimname = ar->dimension_name(ar->dim_begin());
     	    int mapdimsize = ar->dimension_size(ar->dim_begin());
     
     	    if (mapdimname == "") // if dim. name is missing use var. name 
     		    mapdimname = ar->name();
-    
+#endif    
     	    // Find a match to the dimension name and size ?
     	    bool match_found = false;
     	    for (int j=0; j <d_ndims; j++) {
